/*
 *  swimacbasicmodem.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/18/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACBASICMODEM_H__
#define __SWIMACBASICMODEM_H__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetBootVersion - to retrieve the bootloader version
//
// Purpose:	This function returns the device's firmware loader version in a string. 
//			This is the code in the modem that is used to replace the modem's 
//			firmware when upgrading.
//
//			A request is sent to the modem.  The modem's response contains the
//			bootloader version.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			szBVVersion[OUT]:	bootloader version
//
//			sizeBuffer[IN]:		size of buffer provided for the bootloader version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The version string varies in length. It is recommended that a character 
//			string of 80 bytes be allocated to store this return value.
//			The returned string is null terminated.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetBootVersion(SWI_U8 *szBVVersion, SWI_U32 sizeBuffer, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetFirmwareVersion - to retrieve the firmware version
//
// Purpose:	This function returns the device's firmware version in a string.
//
//			A request is sent to the modem.  The modem's response contains the
//			firmware version.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			szFWVersion[OUT]:	firmware version
//
//			sizeBuffer[IN]:		size of buffer provided for the firmware version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The firmware version string varies in length. It is recommended that a 
//			character string of 80 bytes be allocated to store this return value. 
//			Generally the firmware revision string is in the form of Rx-y-z, where x, 
//			y, and z are numbers. These numbers can be up to three digits long each, 
//			but typically should be one or two digits each (for example: R1-2-12).
//			The returned string is null terminated.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetFirmwareVersion(SWI_U8 *szFWVersion, SWI_U32 sizeBuffer, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetHardwareVersion - to retrieve the hardware version
//
// Purpose:	This function returns the device's hardware version in a string.
//
//			A request is sent to the modem.  The modem's response contains the
//			hardware version.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			szHWVersion[OUT]:	hardware version
//
//			sizeBuffer[IN]:		size of buffer provided for the hardware version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The firmware version string varies in length. It is recommended that a 
//			character string of 80 bytes be allocated to store this return value.
//			The returned string is null terminated. 
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetHardwareVersion(SWI_U8 *szHWVersion, SWI_U32 sizeBuffer, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPhoneNumber - Get active phone number
//
// Purpose:     This function returns the phone number from the
//              currently active NAM account profile.
//
// Parameters:  PhoneNumber[OUT]        The destination in which the
//                                      current account phone number is
//                                      returned.
//              BufferSize[IN]          The maximum size of the output
//                                      string (PhoneNumber).
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The phone number is returned as an null-termi-nated
//              ASCII string of 10-15 numerals.
//
//              The current NAM account profile is set with
//              SwiPstSetCurrentNam.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPhoneNumber(SWI_U8 *PhoneNumber, SWI_U32 BufferSize, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetGuiSettings - Get the GUI settings
//
// Purpose:     This function reports the GUI settings for the modem.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              guiSettings[OUT]        GUI settings
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetGuiSettings(SWI_U16 *guiSettings, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetActivationStatus - Get activation status
//
// Purpose:     This function reports the activation status of the
//              modem.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pActivationStatus[OUT]  The destination in which the
//                                      status is returned:
//                                      0 = False
//                                      1 = True
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This function can be used to determine if the
//              modem has been activated with at least one
//              NAM account profile. If not, the application
//              should only offer the user E911 service and a
//              mechanism to activate the modem with the
//              service provider, either by OTASP or direct data
//              entry.
//
//              See "Activation overview" for more
//              on the activation process.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetActivationStatus(SWI_U16 *pActivationStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetSystemTime - Get current network time
//
// Purpose:     This function returns the date and time from the
//              CDMA network.
//
// Parameters:  year[OUT]               Year as a binary number; such as
//                                      0x7D0 for the year 2000
//              month[OUT]              Month in binary
//                                      day Date in the month in binary
//              weekday[OUT]            Day of the week as a numeric:
//                                      0x0001 = Mon
//                                      0x0007 = Sun
//              hour[OUT]               Hour in binary (24-hour clock).
//                                      For example: 0x0016 = 10 PM
//              minute[OUT]             Minutes in binary
//              second[OUT]             Seconds in binary
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Coverage is required to return a valid time.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSystemTime(SWI_U16 *year, SWI_U16 *month, SWI_U16 *day, SWI_U16 *weekDay, SWI_U16 *hour, SWI_U16 *minute, SWI_U16 *second, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetByteCounter - Get xfered byte counts
//
// Purpose:     This function returns the number of bytes trans-mitted
//              and received in the current call
//              (connection).
//
// Parameters:  pSent[OUT]              The number of bytes tranmitted
//              pReceived[OUT]          The number of bytes received
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Counters contain the total bytes sent and
//              received over the local (host/modem) interface.
//              The counter resets when the call is disconnected.
//
//              A notification equivalent is available
//              (SWI_NOTIFY_CallByteCounter) and is the
//              preferred mechanism for tracking this data.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetByteCounter(SWI_U32 *pSent, SWI_U32 *pReceived, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCumulativeByteCounter - Get lifetime xfered kilobyte counts
//
// Purpose:     This function returns the number of kilobytes transmitted
//              and received since this device was last refurbished
//
// Parameters:  pSent[OUT]              The number of kilobytes tranmitted
//              pReceived[OUT]          The number of kilobytes received
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Counters contain the total kilobytes sent and
//              received over the local (host/modem) interface.
//              The counter resets when the device is refurbished.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCumulativeByteCounter(SWI_U32 *pSent, SWI_U32 *pReceived, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiResetTrafficStatistics
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiResetTrafficStatistics();

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetModemOffline - Sets the modem offline
//
// Purpose:     This function set the modem to offline mode. This is typically done before
//              saving data to the modem and then reset the modem with SwiResetModem
//              The benefit to bring the modem to offline mode is to limit modem's operation
//              during this mode.
//				Typical scenarios requiring a modem reset include:
//              - Modem activation
//              - Modifying system select setting (SwiPstSetSystemPref)
//				- Changing the current active NAM (SwiPstSetCurrentNam)
//
// Parameters:  none
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       During this mode, the modem might error out on certain operations like,
//				voice/data/SMS related call.  
//
//				SWI_NOTIFY_Power[_Power.State == SWI_Type_PowerOffline] notification will be sent when
//				the modem completes the offline.  See SWI_NOTIFY_Power for details.
//
//				To exit this mode, application needs to call SwiResetModem.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetModemOffline();

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiLockModem - Toggles security lock state
//
// Purpose:     This function toggles the state of the user security lock.
//
// Parameters:  Password[IN]            The userís passcode to contol the
//                                      modem lock.
//              timeout[IN]             Function timeout in milliseconds
//              pResponse[OUT]          The modem's response to the
//                                      password provided:
//                                      0 = passcode rejected
//                                      1 = accepted - state toggled
//
// Return:      SWI_RCODE_OK            The function executed normally. The 
//                                      actual result of the process is
//                                      returned in the output parameter
//                                      pResponse.
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  The lock state may or may 
//                                      not toggle based on the acceptance or 
//                                      rejection of the passcode provided. 
//
//                                      The application should pause and
//                                      then use SwiGetLockStatus to determine if 
//                                      the modem lock changed state or not. That 
//                                      will determine if a retry of this function 
//                                      is needed.
//
// Notes:       Toggles the lock immediately.
//              Used SwiGetLockStatus() to get the modem's status. Then use
//              SwiLockModem() to toggle the lock. Compare the new state, returned
//              by SwiLockModem() to the initial state to see if it actually
//              changed.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiLockModem(SWI_U8 *Password, SWI_U16 *pResponse, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetLockStatus - Determines lock status of the modem
//
// Purpose:     This function reports the state of the user security lock.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              [OUT[pLockStatus        The status of the user security lock:
//                                      0 = not locked
//                                      1 = locked
//
// Return:          
//
// Notes:           
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLockStatus(SWI_U16 *pLockStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiChangeLockPIN - Change the user passcode
//
// Purpose:     This function changes the userís passcode (PIN).
//
// Parameters:  OldPassword[IN]         The original passcode; to permit
//                                      the user to make the change.
//              NewPassword[IN]         The new setting for the passcode.
//              timeout[IN]             Function timeout in milliseconds
//              pResponse[OUT]          The result of the requested change:
//                                      0 = change rejected
//                                      1 = change accepted
//              
// Return:      SWI_RCODE_OK            The function executed normally. Consult 
//                                      the result of pResponse to determine if 
//                                      the setting was accepted. 
//              SWI_RCODE_FAILED        The operation failed in the modem. This 
//                                      does not indicate a rejection of the 
//                                      OldPassword parameter.
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  The password change still 
//                                      may take place in the modem.
//
// Notes:       This SWI_RCODE_REQUEST_TIMEOUT situation requires special care. If 
//              the OldPassword was accepted, the new setting will be made.  A 
//              subsequent retry will report an invalid password (OldPassword) 
//              because the new password is in effect. On the other hand, if the
//              OldPassword was rejected, the settings are unchanged. A retry will 
//              report an invalid password, because the user failed to match. Both
//              cases give exactly the same result on a retry!  The recommended 
//              course of action is to have the application silently retry the 
//              command using the NewPassword value in both the old and new
//              parameters. If the modem accepts this, then the change is complete. 
//              If the modem rejects it, then OldPassword was likely rejected in 
//              the orginal call and the user will have to start the process
//              over.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiChangeLockPIN(SWI_U8 *OldPassword, SWI_U8 *NewPassword, SWI_U16 *pResponse, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetAutoLock - Gets the current auto-lock setting
//
// Purpose:     This function reports the state of the autolock feature.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              autoLock[OUT]           The status of the autolock feature:
//                                      0 = disabled
//                                      1 = enabled
//
// Return:      See SwiRcodes.h 
//
// Notes:       The setting of autolock is controlled with SwiSetAutoLock.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetAutoLock(SWI_U16 *autoLock, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetAutoLock - Sets auto-lock feature of the modem
//
// Purpose:     This function sets the state of the automatic user
//              security lock on the modem.
//
// Parameters:  autoLock[IN]            The autolock state setting:
//                                      0 = Off
//                                      !0 = Enabled
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h    
//
// Notes:       If you enable the autolock, the lock will be on the
//              next time the modem is started (reset or power cycled).
//              The state of the current autolock setting can be read using 
//              SwiGetAutoLock.
//
//              A locked modem is unlocked with SwiLockModem.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetAutoLock(const SWI_U16 autoLock, SWI_U32 timeout);

//**********************************************************************************
//	SwiGetCallerID - Get the Caller ID
//**********************************************************************************
SWI_RCODE SwiGetCallerID(SWI_U8 *szCallerID, SWI_U32 iLength, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCallerID - Get the Caller ID
//
// Purpose:     This function returns the standard caller ID for
//              the current incoming call (if supported by the service provider).
//
// Parameters:  iLength[IN]             The maximum size of the output
//                                      string (pointed to by szCallerID).
//              timeout[IN]             Function timeout in milliseconds
//              szCallerID[OUT]         The destination in which the caller
//                                      ID string is returned.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       There are two notifications that also return the
//              caller ID of incoming calls (when available):
//                 SWI_NOTIFY_CallCallerID
//                 SWI_NOTIFY_CallExtendedCallerID
//              Use of notifications is preferred over polling commands.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCallerID(SWI_U8 *szCallerID, SWI_U32 iLength, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetAnswerState - Get the answer state
//
// Purpose:     This function reports the mode the modem will
//              use to answer the next incoming call.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              AnswerMode[OUT]         The destination in which the mode
//                                      is returned.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Consult the data type for SWI_TYPE_AnswerState for additional 
//              information on the meaning of the returned setting.
//
//              The setting can be changed using SwiSetAnswerState.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetAnswerState(SWI_TYPE_AnswerState *AnswerMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetAnswerState - Set the answer state
//
// Purpose:     This function sets the mode the modem will use
//              to answer the next incoming call.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//				AnswerMode[IN]          The mode setting to make.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Consult the data type for SWI_TYPE_AnswerState for additional 
//              information on the meaning of the settings.
//
//              The current setting can be read using SwiGetAnswerState.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetAnswerState(const SWI_TYPE_AnswerState AnswerMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetCallAnswerCmd - Answer an incoming call
//
// Purpose:     This function is used to answer an incoming call.
//
// Parameters:  None.
//
// Return:      SWI_RCODE_OK            The function executed normally. This does 
//                                      not mean that the call was successfully 
//                                      answered. Use call notifications
//                                      for the status of the call connection.
//                                      See also SwiGetCallConnectionState.    
//
// Notes:       Don't call this unless you have detected an incoming call request 
//              (ring) via SWI_NOTIFY_CallIncoming.
//
//              The mode the modem will use to answer the call
//              is set by SwiSetAnswerState that must have been
//              set prior to receiving the incoming call notification.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetCallAnswerCmd(void);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetCallFlashCmd - Flash function used during voice calls
//
// Purpose:     This function sends a flash with information to
//              the base station.
//
// Parameters:  SOValue[IN]             Service option to request from base station. 
//              szCallNumber[IN]        Phone number or feature code; can be null 
//                                      if a call number is not required.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Consult the description of the service option
//              flash context in documentation for addtional
//              details.
//
//              Typically this function is called ignoring the context
//              with SOValue = SWI_TYPE_FlashContext_DontCare.  
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetCallFlashCmd(const SWI_TYPE_FlashContext SOValue, SWI_U8 *szCallNumber, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetCallOriginateCmd - Originate a call
//
// Purpose:     This function originates a Voice, QNC, or 1xRTT call / connection 
//              on the AirCard 555 modem.
//
// Parameters:  callType[IN]            The type of call to originate. The
//                                      valid options are:
//                                      SWI_CALL_TYPE_Voice
//                                      SWI_CALL_TYPE_AsyncData
//                                      SWI_CALL_TYPE_PacketData
//              szCallNumber[IN]        The number to dial. You must
//                                      ensure the string contains only
//                                      characters: #, *, 0-9.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The SB555 only uses this command to create a voice call.
//
//
//              SWI_CALL_TYPE_Voice     Used for voice and OTASP calls by both 
//                                      AirCard 555 and SB555 products.
//
//                                      The SB555 creates data calls through DUN. 
//                                      The number dialed determines the service option.    
//
//              SWI_CALL_TYPE_AsyncData 
//                                      Used by the AirCard 555 only, for creating 
//                                      a QNC connection.
//
//              SWI_CALL_TYPE_PacketData 
//                                      Used by the AirCard 555 only, for creating 
//                                      a 1xRTT packet data connection.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetCallOriginateCmd(const SWI_TYPE_CallType callType, SWI_U8 *szCallNumber, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetCallDisconnectCmd - Disconnect the current call
//
// Purpose:     This function disconnects the current call.
//
// Parameters:  None.
//
// Return:      SWI_RCODE_OK            The function executed normally. This does 
//                                      not mean that the call was successfully 
//                                      disconnected. Use call notifications
//                                      for the status of the call connection.
//                                      See also SwiGetCallConnectionState.    
//
// Notes:       None.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetCallDisconnectCmd(void);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCallDuration - Retrieve the duration of the current call
//
// Purpose:     This function reports the elapsed time of the current call
//
// Parameters:  pCallDuration[IN]       Duration of current call in seconds                        
//
// Return:      No special handling.
//              See SwiRcodes.h    
//
// Note:        Applicable to both data and voice calls.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCallDuration(SWI_U32 *pCallDuration, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetRssi - to get the current received signal strength indication.
//
// Purpose:	This function reports the Received Signal Strength Indicator (RSSI).
//
//			A request is sent to the modem.  The modem's response contains the
//			RSSI.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			iRssi[OUT]:			(positive) RSSI value.  Negate the value
//								received to interpret it correctly.
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			SWI_RCODE_UNEXPECTED_RESP - the value returned was outside of the 
//				expected range. The returned data is not likely correct.
//			See SWI_RCODE for other error return codes
//
// Notes:	CDMA does not use an RSSI per se. The modem uses an algorithm 
//			incorporating signal quality elements to produce the numbers 
//			delivered by this function.
//
//			The interpretation is described in the following table:
//
//			-------------------------------------------------
//			|		Value		|			Meaning			|
//			-------------------------------------------------
//			|	-137			|	No signal detected		|
//			|	-136 to -91		|	Very poor				|
//			|	-90 to -86		|	Poor					|
//			|	-85 to -81		|	Fair					|
//			|	-80 to -76		|	Good					|
//			|	> -76			|	Excellent				|
//			-------------------------------------------------
//
//			Use of this function should be reserved to application startup. 
//			There is a notification available in the CDMA2000 1X API 
//			(SWI_NOTIFY_Rssi). Use of notifications is preferred over direct polling.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetRssi(SWI_S32 *iRssi, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiEVDOGetRssi - Get EVDO RSSI
//
// Purpose:     This function gets the current EVDO RSSI.
//
// Parameters:  Rssi[OUT]	Modem preference
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiEVDOGetRssi(SWI_S16 *Rssi, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetRoamingState - to retrieve the roaming state
//
// Purpose:	This function is used to retrieve the roaming state.  The modem is either
//			roaming or on the home network.
//
//			A request is sent to the modem.  The modem's response contains the
//			roaming state.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			eRoaming[OUT]:		roaming state
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	If this function is called while the modem is not in coverage, it 
//			will report being at home. The modem cannot verify that you are roaming 
//			until it can detect coverage and identify the carrier(s).  Use of this 
//			function should be limited. Use of notifications is preferred over
//			direct polling.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetRoamingState(SWI_TYPE_RoamingState *eRoaming, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetRoamingStatus - Report on roaming status
//
// Purpose:     This function reports whether the device has
//              acquired service from a cellular service provider
//              other than that to which the user has subscribed.
//
// Parameters:  lRoamingStatus[OUT]     A pointer to return the status:
//                                      0 = Not roaming
//                                      1 = Roaming
//                                      2 = Non preferred roaming
//                                      >2 = Service provider dependent
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Results when called while not in coverage are
//              undefined. The modem cannot verify that you
//              are roaming until it can detect coverage
//              (SwiGetServiceIndication) and identify the service
//              provider(s).
//
//              Use of this function should be limited. There is a
//              notification available in the CDMA2000 1X API
//              (SWI_NOTIFY_RoamingStatus) that reports the
//              same data. Use of notifications is preferred over
//              direct polling.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetRoamingStatus(SWI_U16* lRoamingStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetHdrRoamStatus - Get HDR Roaming status
//
// Purpose:     This function gets the current roaming status for HDR service
//
// Parameters:  iHdrRoamStatus[OUT]	  Roam status
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetHdrRoamStatus(SWI_U16 *iHdrRoamStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetServiceIndication - Report on service availability
//
// Purpose:     This function reports whether or not there is
//              service in the current location.
//
// Parameters:  iServiceIndicator[OUT]  The current service:
//                                      0 = No service
//                                      1 = Analog (not supported)
//                                      2 = Digital service
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The presence of a CDMA service does not
//              guarantee that connection is possible. The
//              modem may fail to authenticate with the local
//              service provider. E911 service should still be
//              available, even if authentication fails.
//
//              There is a notification equivalent
//              (SWI_NOTIFY_ServiceIndication) to advise the
//              application when entering or leaving coverage.
//              This is preferred over the polling command.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetServiceIndication(SWI_U16 *iServiceIndicator, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCallConnectionState - Get the current connection state
//
// Purpose:     This function reports the state of the modemís
//              current connections.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              CallState[OUT]          The destination in which the
//                                      current call states are returned as
//                                      a single bit-mapped value.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Consult the data type for SWI_TYPE_CallState for additional 
//              information on the meaning of the returned bit mask.
//
//              There is a family of notifications used to indicate
//              any changes in call states.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCallConnectionState(SWI_TYPE_CallState *CallState, SWI_U32 timeout);


//**********************************************************************************
//	SwiGetBasicModemData
//		This call returns all the Modem data in one structure
//		the primary use is to check all the "GET" calls for
//		Modem
//**********************************************************************************
#define BASIC_BOOT_VERSION_LENGTH 80
#define BASIC_FIRMWARE_VERSION_LENGTH 80
#define BASIC_HARDWARE_VERSION_LENGTH 80
#define BASIC_PHONE_NUMBER_LENGTH 20
#define BASIC_CALLER_ID_LENGTH 40
typedef struct allBasicModemData
{
	SWI_RCODE				_ret[20];
	SWI_U8					_bootVersion[BASIC_BOOT_VERSION_LENGTH];
	SWI_U8					_firmwareVersion[BASIC_FIRMWARE_VERSION_LENGTH];
	SWI_U8					_hardwareVersion[BASIC_HARDWARE_VERSION_LENGTH];
	SWI_U8					_phoneNumber[BASIC_PHONE_NUMBER_LENGTH];
	SWI_U16					_guiSettings;
	SWI_U16					_activationStatus;
	SWI_U16					_systemYear;
	SWI_U16					_systemMonth;
	SWI_U16					_systemDay;
	SWI_U16					_systemWeekDay;
	SWI_U16					_systemHour;
	SWI_U16					_systemMinute;
	SWI_U16					_systemSecond;
	SWI_U32					_bytesSent;
	SWI_U32					_bytesReceived;
	SWI_U16					_modemLocked;
	SWI_U16					_autoLockEnabled;
	SWI_U8					_callerID[BASIC_CALLER_ID_LENGTH];
	SWI_TYPE_AnswerState	_answerState;
	SWI_U32					_callDuration;
	SWI_S32					_rssi;
	SWI_TYPE_RoamingState	_roamingState;
	SWI_U16					_roamingStatus;
	SWI_U16					_hdrRoamingStatus;
	SWI_U16					_serviceIndication;
	SWI_TYPE_CallState		_callConnectionState;
	SWI_U32					_cumulativeBytesSent;
	SWI_U32					_cumulativeBytesReceived;

} allBasicModemData;

SWI_RCODE SwiGetBasicModemData(allBasicModemData *data);


#ifdef __cplusplus
}
#endif

#endif // __SWIMACBASICMODEM_H__
